==> xblast_2.0.orig.tar.gz: XBlast-2.0.orig/main.h <==
/*
 * Programm XBLAST V1.2.4 or higher
 * (C) by Oliver Vogel (e-mail: vogel@ikp.uni-koeln.de)
 * January 24th 1996
 * started August 1993
 *
 * File: main.c 
 *
 * include file for main.h
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public Licences as published
 * by the Free Software Foundation; either version 2; or (at your option)
 * any later version
 *
 * This program is distributed in the hope that it will entertaining,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILTY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Publis License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _MAIN_H
#define _MAIN_H

/*
 * global variables
 */
#ifndef _MAIN_C
extern int cur_bomb_time;
extern int defaultBMT;
extern int buttonBMT;
extern int game_time;
extern int num_player;
extern int game_mode;
extern int FrameTime;
extern BMPlayer player_stat[MAX_PLAYER+1];
#endif

/*
 * global prototypes
 */
#ifdef _MAIN_C
#define _EXTERN 
#else
#define _EXTERN extern
#endif

#ifdef __STDC__
_EXTERN void bm_fatal (char *text, char *prog);
_EXTERN void drop_bomb (int player, BMPlayer *ps, int type);
_EXTERN void print_player_lives (int player, int flag);
_EXTERN void add_player_num_bomb (int player);
_EXTERN  int check_b_near (int x, int y);
#else
_EXTERN void bm_fatal ();
_EXTERN void drop_bomb ();
_EXTERN void print_player_lives ();
_EXTERN void add_player_num_bomb ();
_EXTERN int check_b_near ();
#endif

#undef _EXTERN

#endif
/*
 * end of main.h
 */

==> xblast-2.2.tar.gz: XBlast-2.2/main.h <==
/*
 * Program XBLAST V2.1.8 or higher
 * (C) by Oliver Vogel (e-mail: vogel@ikp.uni-koeln.de)
 * September 8th 1996
 * started August 1993
 *
 * File: main.c 
 *
 * include file for main.h
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public Licences as published
 * by the Free Software Foundation; either version 2; or (at your option)
 * any later version
 *
 * This program is distributed in the hope that it will entertaining,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILTY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Publis License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _MAIN_H
#define _MAIN_H

/*
 * global variables
 */
#ifndef _MAIN_C
extern int game_time;
extern int FrameTime;
#endif

/*
 * global prototypes
 */
#ifdef _MAIN_C
#define _EXTERN 
#else
#define _EXTERN extern
#endif

#ifdef __STDC__
_EXTERN void setup_funcs (BMFuncData *cur_level);
_EXTERN void setup_players(unsigned long g_mode, BMPlayerData *level);
_EXTERN void drop_bomb (BMPlayer *ps, int type);
_EXTERN void kill_player_at (int x, int y);
_EXTERN int check_b_near (int x, int y);
_EXTERN void exit_prg (int status);
#else
_EXTERN void setup_funcs ();
_EXTERN void setup_players();
_EXTERN void drop_bomb ();
_EXTERN void kill_player_at ();
_EXTERN int check_b_near ();
_EXTERN void exit_prg ();
#endif

#undef _EXTERN

#endif
/*
 * end of main.h
 */
